Structs
- Memory
Barcode Scanner Host - Memory
Biometric Host - In-process biometric host for tests and non-OS environments.
- Memory
Bluetooth Host - Memory
Camera Host - Memory
Clipboard Host - In-process clipboard host for tests and non-OS environments.
- Memory
Geolocation Host - Memory
Haptic Host - Memory
Microphone Host - Memory
NfcHost - In-process NFC host for smoke tests and non-OS environments.
- Memory
Notification Host - Minimal in-process host useful for smoke tests and non-OS environments.
- Memory
Passkey Host - In-process passkey host for tests and non-OS environments.
- Memory
Volume Host - Memory
Wifi Host - Mobile
App - Unsupported
Barcode Scanner Host - Unsupported
Biometric Host - Default provider used when the active shell has no biometric integration.
- Unsupported
Bluetooth Host - Unsupported
Camera Host - Unsupported
Geolocation Host - Unsupported
Haptic Host - Unsupported
Microphone Host - Unsupported
NfcHost - Default provider used when the active shell has no NFC integration.
- Unsupported
Notification Host - Default provider used until a shell installs a platform-specific host.
- Unsupported
Passkey Host - Default provider used when the active shell has no passkey integration.
- Unsupported
Volume Host - Unsupported
Wifi Host
Traits
- Barcode
Scanner Host - Host-side barcode scanner provider.
- Biometric
Host - Host-side biometric provider used by shell capability registration.
- Bluetooth
Host - Host-side Bluetooth provider.
- Camera
Host - Host-side camera and flashlight provider.
- Clipboard
Host - Host-side clipboard provider used by shell capability registration.
- Geolocation
Host - Host-side geolocation provider used by shell capability registration.
- Haptic
Host - Host-side haptic feedback provider used by shell capability registration.
- Microphone
Host - Host-side microphone provider.
- NfcHost
- Host-side NFC provider used by shell capability registration.
- Notification
Host - Host-side notification provider used by the shell capability registry.
- Passkey
Host - Host-side passkey/WebAuthn provider used by shell capability registration.
- Volume
Host - Host-side volume-control provider.
- Wifi
Host - Host-side Wi-Fi provider.