pub struct UnsupportedBarcodeScannerHost;Trait Implementations
Sourceimpl BarcodeScannerHost for UnsupportedBarcodeScannerHost
impl BarcodeScannerHost for UnsupportedBarcodeScannerHost
Sourcefn scan(
&self,
_request: BarcodeScanRequest,
) -> Result<BarcodeScanResults, BarcodeScannerError>
fn scan( &self, _request: BarcodeScanRequest, ) -> Result<BarcodeScanResults, BarcodeScannerError>
Runs a live barcode scanning session and returns decoded results.
Sourcefn decode_image(
&self,
_request: BarcodeImageDecodeRequest,
) -> Result<BarcodeScanResults, BarcodeScannerError>
fn decode_image( &self, _request: BarcodeImageDecodeRequest, ) -> Result<BarcodeScanResults, BarcodeScannerError>
Decodes barcode results from image bytes supplied by the app.
Sourcefn cancel_scan(&self) -> Result<(), BarcodeScannerError>
fn cancel_scan(&self) -> Result<(), BarcodeScannerError>
Cancels the active live barcode scanning session.
Sourceimpl Default for UnsupportedBarcodeScannerHost
impl Default for UnsupportedBarcodeScannerHost
Sourcefn default() -> UnsupportedBarcodeScannerHost
fn default() -> UnsupportedBarcodeScannerHost
Returns the “default value” for a type. Read more