pub struct UnsupportedBluetoothHost;Trait Implementations
Sourceimpl BluetoothHost for UnsupportedBluetoothHost
impl BluetoothHost for UnsupportedBluetoothHost
Sourcefn availability(&self) -> Result<BluetoothAvailability, BluetoothError>
fn availability(&self) -> Result<BluetoothAvailability, BluetoothError>
Returns adapter, permission, and Bluetooth mode availability.
Sourcefn request_permission(
&self,
_request: BluetoothPermissionRequest,
) -> Result<BluetoothPermission, BluetoothError>
fn request_permission( &self, _request: BluetoothPermissionRequest, ) -> Result<BluetoothPermission, BluetoothError>
Requests Bluetooth or nearby-device permission from the host.
Sourcefn scan_devices(
&self,
_request: BluetoothScanRequest,
) -> Result<BluetoothScanResult, BluetoothError>
fn scan_devices( &self, _request: BluetoothScanRequest, ) -> Result<BluetoothScanResult, BluetoothError>
Scans for Bluetooth devices matching the supplied filters.
Sourcefn connect_device(
&self,
_request: BluetoothConnectRequest,
) -> Result<BluetoothConnection, BluetoothError>
fn connect_device( &self, _request: BluetoothConnectRequest, ) -> Result<BluetoothConnection, BluetoothError>
Connects to a Bluetooth device and returns a connection handle.
Sourcefn disconnect_device(
&self,
_request: BluetoothDisconnectRequest,
) -> Result<(), BluetoothError>
fn disconnect_device( &self, _request: BluetoothDisconnectRequest, ) -> Result<(), BluetoothError>
Disconnects a previously opened Bluetooth connection.
Sourcefn read_characteristic(
&self,
_request: BluetoothReadRequest,
) -> Result<BluetoothReadResult, BluetoothError>
fn read_characteristic( &self, _request: BluetoothReadRequest, ) -> Result<BluetoothReadResult, BluetoothError>
Reads bytes from a characteristic on an active connection.
Sourcefn write_characteristic(
&self,
_request: BluetoothWriteRequest,
) -> Result<(), BluetoothError>
fn write_characteristic( &self, _request: BluetoothWriteRequest, ) -> Result<(), BluetoothError>
Writes bytes to a characteristic on an active connection.
Sourcefn start_advertising(
&self,
_request: BluetoothAdvertiseRequest,
) -> Result<BluetoothAdvertiseReceipt, BluetoothError>
fn start_advertising( &self, _request: BluetoothAdvertiseRequest, ) -> Result<BluetoothAdvertiseReceipt, BluetoothError>
Starts Bluetooth advertising where the platform permits it.
Sourcefn stop_advertising(
&self,
_request: BluetoothStopAdvertiseRequest,
) -> Result<(), BluetoothError>
fn stop_advertising( &self, _request: BluetoothStopAdvertiseRequest, ) -> Result<(), BluetoothError>
Stops a previously started Bluetooth advertisement.
Sourceimpl Debug for UnsupportedBluetoothHost
impl Debug for UnsupportedBluetoothHost
Sourceimpl Default for UnsupportedBluetoothHost
impl Default for UnsupportedBluetoothHost
Sourcefn default() -> UnsupportedBluetoothHost
fn default() -> UnsupportedBluetoothHost
Returns the “default value” for a type. Read more