pub struct UnsupportedCameraHost;Trait Implementations
Sourceimpl CameraHost for UnsupportedCameraHost
impl CameraHost for UnsupportedCameraHost
Sourcefn availability(&self) -> Result<CameraAvailability, CameraError>
fn availability(&self) -> Result<CameraAvailability, CameraError>
Returns camera permission state and host-visible camera devices.
Sourcefn request_permission(
&self,
_request: CameraPermissionRequest,
) -> Result<CameraPermission, CameraError>
fn request_permission( &self, _request: CameraPermissionRequest, ) -> Result<CameraPermission, CameraError>
Requests camera permission and returns the resulting permission state.
Sourcefn capture_photo(
&self,
_request: CameraCaptureRequest,
) -> Result<CameraCapture, CameraError>
fn capture_photo( &self, _request: CameraCaptureRequest, ) -> Result<CameraCapture, CameraError>
Captures a still image according to the selected camera, format, flash, and quality request.
Sourcefn set_flashlight(
&self,
_request: CameraFlashlightRequest,
) -> Result<(), CameraError>
fn set_flashlight( &self, _request: CameraFlashlightRequest, ) -> Result<(), CameraError>
Enables, disables, or adjusts the selected camera flashlight where available.
Sourcefn cancel_capture(&self) -> Result<(), CameraError>
fn cancel_capture(&self) -> Result<(), CameraError>
Cancels an active camera capture flow.
Sourceimpl Debug for UnsupportedCameraHost
impl Debug for UnsupportedCameraHost
Sourceimpl Default for UnsupportedCameraHost
impl Default for UnsupportedCameraHost
Sourcefn default() -> UnsupportedCameraHost
fn default() -> UnsupportedCameraHost
Returns the “default value” for a type. Read more