pub struct UnsupportedGeolocationHost;Trait Implementations
Sourceimpl Debug for UnsupportedGeolocationHost
impl Debug for UnsupportedGeolocationHost
Sourceimpl Default for UnsupportedGeolocationHost
impl Default for UnsupportedGeolocationHost
Sourcefn default() -> UnsupportedGeolocationHost
fn default() -> UnsupportedGeolocationHost
Returns the “default value” for a type. Read more
Sourceimpl GeolocationHost for UnsupportedGeolocationHost
impl GeolocationHost for UnsupportedGeolocationHost
Sourcefn permission(&self) -> Result<GeolocationPermission, GeolocationError>
fn permission(&self) -> Result<GeolocationPermission, GeolocationError>
Returns the current location permission state without showing a prompt.
Sourcefn request_permission(
&self,
_request: GeolocationPermissionRequest,
) -> Result<GeolocationPermission, GeolocationError>
fn request_permission( &self, _request: GeolocationPermissionRequest, ) -> Result<GeolocationPermission, GeolocationError>
Requests location permission with precision and background preferences.
Sourcefn current_position(
&self,
_request: GeolocationPositionRequest,
) -> Result<GeolocationPosition, GeolocationError>
fn current_position( &self, _request: GeolocationPositionRequest, ) -> Result<GeolocationPosition, GeolocationError>
Returns the current position according to accuracy, timeout, and cache rules.