pub struct UnsupportedVolumeHost;Trait Implementations
Sourceimpl Debug for UnsupportedVolumeHost
impl Debug for UnsupportedVolumeHost
Sourceimpl Default for UnsupportedVolumeHost
impl Default for UnsupportedVolumeHost
Sourcefn default() -> UnsupportedVolumeHost
fn default() -> UnsupportedVolumeHost
Returns the “default value” for a type. Read more
Sourceimpl VolumeHost for UnsupportedVolumeHost
impl VolumeHost for UnsupportedVolumeHost
Sourcefn get_level(&self, _stream: VolumeStream) -> Result<VolumeLevel, VolumeError>
fn get_level(&self, _stream: VolumeStream) -> Result<VolumeLevel, VolumeError>
Reads the current level and mute state for one logical volume stream.
Sourcefn set_level(
&self,
_request: VolumeSetRequest,
) -> Result<VolumeLevel, VolumeError>
fn set_level( &self, _request: VolumeSetRequest, ) -> Result<VolumeLevel, VolumeError>
Sets the level and optional mute state for one logical volume stream.
Sourcefn adjust_level(
&self,
_request: VolumeAdjustRequest,
) -> Result<VolumeLevel, VolumeError>
fn adjust_level( &self, _request: VolumeAdjustRequest, ) -> Result<VolumeLevel, VolumeError>
Adjusts one logical volume stream relative to its current state.